@@ -18,19 +18,28 @@ from bokeh.server.server import Server
 from bokeh.application import Application
 from bokeh.application.handlers.function import FunctionHandler
 from bokeh.plotting import figure, ColumnDataSource
-from bokeh.models import Range1d
+from bokeh.models import Range
 from bokeh.palettes import Category20_20 as palette
+from bokeh.resources import Resources
+from bokeh.embed import file_html
 
 from bokeh.plotting import save, output_file
 from bokeh.layouts import gridplot, column, row
 from bokeh.models.widgets import CheckboxGroup
 from bokeh.models.widgets.buttons import Button
 from bokeh.models.widgets import TextInput
-from bokeh.models import Panel, Tabs
+from bokeh.models import Tabs
 from bokeh.models import DataTable, TableColumn
 from bokeh.models import CustomJS
 from bokeh import events
 
+# In bokeh 2.4.8 -> 3.0.3 Panel was removed.
+# TabPanel can be used instead.
+try:
+    from bokeh.models import Panel
+except ImportError:
+    from bokeh.models import TabPanel as Panel
+
 class UpdateEvent(object):
     """@brief Responsible for holding the state of an event sent from a non GUI thread
               to the GUI thread context in order to update the GUI. The details of these
@@ -82,16 +91,20 @@ class TabbedGUI(object):
            @param height The height of the plot area in pixels.
            @return A figure instance."""
         if yRangeLimits and len(yRangeLimits) == 2:
-            yrange = Range1d(yRangeLimits[0], yRangeLimits[1])
+            yrange = Range(yRangeLimits[0], yRangeLimits[1])
+            fig = figure(title=title,
+                         x_axis_type="datetime",
+                         x_axis_location="below",
+                         y_range=yrange,
+                         plot_width=width,
+                         plot_height=height)
         else:
-            yrange = None
+            fig = figure(title=title,
+                         x_axis_type="datetime",
+                         x_axis_location="below",
+                         plot_width=width,
+                         plot_height=height)
 
-        fig = figure(title=title,
-                     x_axis_type="datetime",
-                     x_axis_location="below",
-                     y_range=yrange,
-                     plot_width=width,
-                     plot_height=height)
         fig.yaxis.axis_label = yAxisName
         return fig
 
@@ -187,10 +200,15 @@ class TimeSeriesPlotter(TabbedGUI):
         if not line_color:
             line_color = next(self._colors)
 
-        fig.line(source=src,
-                 line_color = line_color,
-                 legend_label = legend_label,
-                 line_width = line_width)
+        if legend_label is not None and len(legend_label) > 0:
+                fig.line(source=src,
+		         line_color = line_color,
+                         legend_label = legend_label,
+                         line_width = line_width)
+        else:
+                fig.line(source=src,
+                         line_color = line_color,
+                         line_width = line_width)
         self._srcList.append(src)
 
     def _update(self):
@@ -237,7 +255,7 @@ class TimeSeriesPlotter(TabbedGUI):
 
     def _getPlotPanel(self):
         """@brief Add tab that shows plot data updates."""
-        self._grid = gridplot(children = self._figTable, sizing_mode = 'scale_both',  toolbar_location='left')
+        self._grid = gridplot(children = self._figTable, toolbar_location='left')
 
         if self._topCtrlPanel:
             checkbox1 = CheckboxGroup(labels=["Plot Data"], active=[0, 1],max_width=70)
@@ -305,8 +323,10 @@ class TimeSeriesPlotter(TabbedGUI):
 
 class StatusBarWrapper(object):
     """@brief Responsible for presenting a single status line of text in a GUI
-              that runs the width of the page (normally at the bottom)."""
-    def __init__(self):
+              that runs the width of the page (normally at the bottom).
+       @param sizing_mode The widget sizing mode. By default the status bar will streach accross the width of the layout.
+       @param height The height of the status bar in pixels. Default 50 gives good L&F on most browsers."""
+    def __init__(self, sizing_mode="stretch_width", height=50):
         data = dict(
             status = [],
         )
@@ -315,7 +335,12 @@ class StatusBarWrapper(object):
         columns = [
                 TableColumn(field="status", title="Status"),
             ]
-        self.statusBar = DataTable(source=self.source, columns=columns, header_row=True, index_position=None)
+        self.statusBar = DataTable(source=self.source,
+                                   columns=columns,
+                                   header_row=True,
+                                   index_position=None,
+                                   sizing_mode=sizing_mode,
+                                   height=height)
 
     def getWidget(self):
         """@brief return an instance of the status bar widget to be added to a layout."""
@@ -495,12 +520,12 @@ class SingleAppServer(object):
         self._serverThread = threading.Thread(target=self.runBlockingBokehServer, args=(appMethod,))
         self._serverThread.setDaemon(True)
         self._serverThread.start()
-        
+
     def app(self, doc):
         """@brief Start the process of creating an app.
            @param doc The document to add the plot to."""
         raise NotImplementedError("app() method not implemented by {}".format(self.__class__.__name__))
-    
+
 class GUIModel_A(SingleAppServer):
     """@brief This class is responsible for providing a mechanism for creating a GUI as
               simply as possible with some common features that can be updated dynamically.
@@ -525,7 +550,7 @@ class GUIModel_A(SingleAppServer):
                                        BOKEH_THEME_CONTRAST)
     DEFAULT_BOKEH_THEME             = BOKEH_THEME_NAMES[0]
 
-    def __init__(self, docTitle, 
+    def __init__(self, docTitle,
                  bokehServerPort=SingleAppServer.GetNextUnusedPort(),
                  includeSaveHTML=True,
                  theme=DEFAULT_BOKEH_THEME,
@@ -535,7 +560,7 @@ class GUIModel_A(SingleAppServer):
            @param includeSaveHTML If True include widgets at the bottom of the web page for saving it as an HTML file.
            @param theme The theme that defines the colours used by the GUI (default=caliber). BOKEH_THEME_NAMES defines the
                         available themes.
-           @param updatePollPeriod The GUI update poll period in milli seconds. 
+           @param updatePollPeriod The GUI update poll period in milli seconds.
            @param bokehServerPort The TCP port to bind the server to."""
         super().__init__(bokehPort=bokehServerPort)
         self._docTitle              = docTitle          # The HTML page title shown in the browser window.
@@ -596,7 +621,7 @@ class GUIModel_A(SingleAppServer):
             if self._includeSaveHTML:
                 self._addHTMLSaveWidgets()
             self._guiTable.append([self._statusBar.getWidget()])
-            gp = gridplot( children = self._guiTable, sizing_mode='stretch_width', toolbar_location="above", merge_tools=True)
+            gp = gridplot( children = self._guiTable, toolbar_location="above", merge_tools=True)
             self._doc.add_root( gp )
             self._appInitComplete = True
 
@@ -667,8 +692,8 @@ class GUIModel_A(SingleAppServer):
                         msg = "Saving {}. Please wait...".format(self.fileToSave.value)
                         self._info(msg)
                         self._setStatus(msg)
-                        output_file(filename=self.fileToSave.value, title="LPTest Static HTML file")
-                        save(self._doc)
+                        # Static appears in the web browser tab to indicate a static HTML file to the user.
+                        self.save(self.fileToSave.value, title="Static: {}".format(self._doc.title))
                         self._setStatus( "Saved {}".format(self.fileToSave.value) )
                     else:
                         self._setStatus( "{} exists but no write access.".format(filePath) )
@@ -679,6 +704,29 @@ class GUIModel_A(SingleAppServer):
         except Exception as ex:
             self._statusBar.setStatus( str(ex) )
 
+    def save(self, filename, title=None, theme=None):
+        """@brief Save the state of the document to an HTML file.
+                  This was written to allow the suppression of Javascript warnings
+                  as previously the bokeh save method was called.
+           @param filename The filename to save.
+           @param title The document title. If left as Non then the title of the current page is used.
+           @param theme The bokeh theme. If left as None then the theme used by the current page is used."""
+        if theme is None:
+            theme = self._doc.theme
+
+        if title is None:
+            title = self._doc.title
+
+        html = file_html(self._doc,
+                         Resources(mode=None),
+                         title=title,
+                         template=None,
+                         theme=theme,
+                         suppress_callback_warning=True)
+
+        with open(filename, mode="w", encoding="utf-8") as f:
+            f.write(html)
+
     def _setStatus(self, msg):
         """@brief Set the display message in the status bar at the bottom of the GUI.
            @param msg The message to be displayed."""
